@@ -7,6 +7,7 @@ use PhpAmqpLib\Exception\AMQPConnectionClosedException;
 use PhpAmqpLib\Exception\AMQPProtocolChannelException;
 use PhpAmqpLib\Exception\AMQPRuntimeException;
 use PhpAmqpLib\Message\AMQPMessage;
+use PhpAmqpLib\Wire;
 use PhpAmqpLib\Wire\AMQPReader;
 use PhpAmqpLib\Wire\AMQPWriter;
 
@@ -649,7 +650,7 @@ class AMQPChannel extends AbstractChannel
      * @param array|\PhpAmqpLib\Wire\AMQPTable $arguments
      * @param int|null $ticket
      * @throws \PhpAmqpLib\Exception\AMQPTimeoutException if the specified operation timeout was exceeded
-     * @return mixed|null
+     * @return array|null
      */
     public function queue_declare(
         $queue = '',
@@ -865,6 +866,7 @@ class AMQPChannel extends AbstractChannel
      */
     protected function get_keys_less_or_equal(array $messages, $value)
     {
+        $value = (int) $value;
         $keys = array_reduce(
             array_keys($messages),
 
@@ -872,7 +874,7 @@ class AMQPChannel extends AbstractChannel
              * @param string $key
              */
             function ($keys, $key) use ($value) {
-                if (bccomp($key, $value, 0) <= 0) {
+                if ($key <= $value) {
                     $keys[] = $key;
                 }
 
@@ -987,7 +989,7 @@ class AMQPChannel extends AbstractChannel
             $no_ack,
             $exclusive,
             $nowait,
-            $this->protocolVersion == '0.9.1' ? $arguments : null
+            $this->protocolVersion === Wire\Constants091::VERSION ? $arguments : null
         );
 
         $this->send_method_frame(array($class_id, $method_id), $args);
@@ -1180,7 +1182,7 @@ class AMQPChannel extends AbstractChannel
 
         if ($this->next_delivery_tag > 0) {
             $this->published_messages[$this->next_delivery_tag] = $msg;
-            $this->next_delivery_tag = bcadd($this->next_delivery_tag, '1', 0);
+            $this->next_delivery_tag++;
         }
     }
 
@@ -1240,7 +1242,7 @@ class AMQPChannel extends AbstractChannel
 
             if ($this->next_delivery_tag > 0) {
                 $this->published_messages[$this->next_delivery_tag] = $msg;
-                $this->next_delivery_tag = bcadd($this->next_delivery_tag, '1', 0);
+                $this->next_delivery_tag++;
             }
         }
 
@@ -1429,7 +1431,9 @@ class AMQPChannel extends AbstractChannel
      * Waits for pending acks and nacks from the server.
      * If there are no pending acks, the method returns immediately
      *
-     * @param int $timeout Waits until $timeout value is reached
+     * @param int|float $timeout Waits until $timeout value is reached
+     * @throws \PhpAmqpLib\Exception\AMQPTimeoutException
+     * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
      */
     public function wait_for_pending_acks($timeout = 0)
     {
@@ -1437,20 +1441,19 @@ class AMQPChannel extends AbstractChannel
             $this->waitHelper->get_wait('basic.ack'),
             $this->waitHelper->get_wait('basic.nack'),
         );
-
-        while (count($this->published_messages) !== 0) {
-            if ($timeout > 0) {
-                $this->wait($functions, true, $timeout);
-            } else {
-                $this->wait($functions);
-            }
+        $timeout = max(0, $timeout);
+        while (!empty($this->published_messages)) {
+            $this->wait($functions, false, $timeout);
         }
     }
 
     /**
-     * Waits for pending acks, nacks and returns from the server. If there are no pending acks, the method returns immediately.
+     * Waits for pending acks, nacks and returns from the server.
+     * If there are no pending acks, the method returns immediately.
      *
-     * @param int $timeout If set to value > 0 the method will wait at most $timeout seconds for pending acks.
+     * @param int|float $timeout If set to value > 0 the method will wait at most $timeout seconds for pending acks.
+     * @throws \PhpAmqpLib\Exception\AMQPTimeoutException
+     * @throws \PhpAmqpLib\Exception\AMQPRuntimeException
      */
     public function wait_for_pending_acks_returns($timeout = 0)
     {
@@ -1460,12 +1463,9 @@ class AMQPChannel extends AbstractChannel
             $this->waitHelper->get_wait('basic.return'),
         );
 
-        while (count($this->published_messages) !== 0) {
-            if ($timeout > 0) {
-                $this->wait($functions, true, $timeout);
-            } else {
-                $this->wait($functions);
-            }
+        $timeout = max(0, $timeout);
+        while (!empty($this->published_messages)) {
+            $this->wait($functions, false, $timeout);
         }
     }
 
