@@ -16,16 +16,6 @@ class MiscHelper
         return sprintf('%d,%d', $a[0], $a[1]);
     }
 
-    /**
-     * @param string $bytes
-     */
-    public static function saveBytes($bytes)
-    {
-        $fh = fopen('/tmp/bytes', 'wb');
-        fwrite($fh, $bytes);
-        fclose($fh);
-    }
-
     /**
      * Gets a number (either int or float) and returns an array containing its integer part as first element and its
      * decimal part mutliplied by 10^6. Useful for some PHP stream functions that need seconds and microseconds as
