@@ -1,13 +1,16 @@
 <?php
-include(__DIR__ . '/config.php');
+
+require __DIR__ . '/config.php';
 
 use PhpAmqpLib\Connection\AMQPStreamConnection;
+use PhpAmqpLib\Exception\AMQPTimeoutException;
 use PhpAmqpLib\Exchange\AMQPExchangeType;
 use PhpAmqpLib\Message\AMQPMessage;
+use PhpAmqpLib\Wire\AMQPTable;
 
-$bindingKeys = array_slice($argv, 1);
-if (empty($bindingKeys)) {
-    file_put_contents('php://stderr', "Usage: $argv[0] [binding_key]\n");
+$headers = array_slice($argv, 1);
+if (empty($headers)) {
+    file_put_contents('php://stderr', "Usage: $argv[0] [header1=value1] [header2=value2]\n");
     exit(1);
 }
 
@@ -16,14 +19,18 @@ $connection = new AMQPStreamConnection(HOST, PORT, USER, PASS, VHOST);
 $channel = $connection->channel();
 
 $exchangeName = 'topic_headers_test';
-$channel->exchange_declare($exchangeName, AMQPExchangeType::TOPIC, false, false, true);
+$channel->exchange_declare($exchangeName, AMQPExchangeType::HEADERS);
 
-list($queueName, ,) = $channel->queue_declare("", false, false, true, true);
+list($queueName, ,) = $channel->queue_declare('', false, false, true);
 
-foreach ($bindingKeys as $bindingKey) {
-    $channel->queue_bind($queueName, $exchangeName, $bindingKey);
+$bindArguments = [];
+foreach ($headers as $header) {
+    list ($key, $value) = explode('=', $header, 2);
+    $bindArguments[$key] = $value;
 }
 
+$channel->queue_bind($queueName, $exchangeName, '', false, new AMQPTable($bindArguments));
+
 echo ' [*] Waiting for logs. To exit press CTRL+C', "\n";
 
 $callback = function (AMQPMessage $message) {
@@ -35,7 +42,10 @@ $callback = function (AMQPMessage $message) {
 
 $channel->basic_consume($queueName, '', false, true, true, false, $callback);
 while ($channel->is_consuming()) {
-    $channel->wait();
+    try {
+        $channel->wait(null, false, 2);
+    } catch (AMQPTimeoutException $exception) {
+    }
     echo '*' . PHP_EOL;
 }
 
