@@ -2,19 +2,29 @@
 
 namespace PhpAmqpLib\Tests\Functional\Channel;
 
+use PhpAmqpLib\Channel\AMQPChannel;
+use PhpAmqpLib\Connection\AbstractConnection;
 use PhpAmqpLib\Connection\AMQPSocketConnection;
 use PHPUnit\Framework\TestCase;
 
+/**
+ * @group connection
+ */
 abstract class ChannelTestCase extends TestCase
 {
+    /** @var AbstractConnection */
     protected $connection;
 
+    /** @var AMQPChannel */
     protected $channel;
 
+    /** @var object */
     protected $exchange;
 
+    /** @var object */
     protected $queue;
 
+    /** @var object */
     protected $message;
 
     public function setUp()
@@ -39,9 +49,13 @@ abstract class ChannelTestCase extends TestCase
 
     public function tearDown()
     {
-        $this->channel->close();
-        $this->channel = null;
-        $this->connection->close();
-        $this->connection = null;
+        if ($this->channel) {
+            $this->channel->close();
+            $this->channel = null;
+        }
+        if ($this->connection) {
+            $this->connection->close();
+            $this->connection = null;
+        }
     }
 }
