@@ -5,6 +5,9 @@ namespace PhpAmqpLib\Tests\Functional;
 use PhpAmqpLib\Message\AMQPMessage;
 use PhpAmqpLib\Tests\Functional\Channel\ChannelTestCase;
 
+/**
+ * @group connection
+ */
 class DirectExchangeTest extends ChannelTestCase
 {
     public function setUp()
@@ -22,7 +25,7 @@ class DirectExchangeTest extends ChannelTestCase
     {
         $this->connection->close();
 
-        $this->channel->exchange_declare($this->exchange->name, 'direct', false, true, false);
+        $this->channel->exchange_declare($this->exchange->name, 'direct', false, false, false);
     }
 
     /**
@@ -33,7 +36,7 @@ class DirectExchangeTest extends ChannelTestCase
     {
         $this->channel->close();
 
-        $this->channel->exchange_declare($this->exchange->name, 'direct', false, true, false);
+        $this->channel->exchange_declare($this->exchange->name, 'direct', false, false, false);
     }
 
     /**
